==> mokkery-runtime-jvm-1.9.20-1.4.0-javadoc.jar: mokkery-runtime/dev.mokkery.matcher.varargs/-var-arg-matcher/-any-of/index.md <==
//[mokkery-runtime](../../../../index.md)/[dev.mokkery.matcher.varargs](../../index.md)/[VarArgMatcher](../index.md)/[AnyOf](index.md)

# AnyOf

@DelicateMokkeryApi

data class [AnyOf](index.md)(type: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;) : [VarArgMatcher.Base](../-base/index.md)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; 

Matches any sequence of varargs.

#### Parameters

common

| | |
|---|---|
| type | of vararg element to provide vararg type information in [AnyOf.toString](to-string.md) |

## Constructors

| | |
|---|---|
| [AnyOf](-any-of.md) | [common]<br>constructor(type: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;) |

## Functions

| Name | Summary |
|---|---|
| [matches](../-base/matches.md) | [common]<br>override fun [matches](../-base/matches.md)(arg: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [matchesVarargs](matches-varargs.md) | [common]<br>open override fun [matchesVarargs](matches-varargs.md)(varargs: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [propagateCapture](../../../dev.mokkery.matcher.capture/propagate-capture.md) | [common]<br>fun &lt;[T](../../../dev.mokkery.matcher.capture/propagate-capture.md)&gt; [ArgMatcher](../../../dev.mokkery.matcher/-arg-matcher/index.md)&lt;[T](../../../dev.mokkery.matcher.capture/propagate-capture.md)&gt;.[propagateCapture](../../../dev.mokkery.matcher.capture/propagate-capture.md)(value: [T](../../../dev.mokkery.matcher.capture/propagate-capture.md))<br>Helper function to propagate capture for [dev.mokkery.matcher.ArgMatcher.Composite](../../../dev.mokkery.matcher/-arg-matcher/-composite/index.md). |
| [toString](to-string.md) | [common]<br>open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

==> mokkery-runtime-jvm-1.9.24-1.7.0-javadoc.jar: mokkery-runtime/dev.mokkery.matcher.varargs/-var-arg-matcher/-any-of/index.md <==
//[mokkery-runtime](../../../../index.md)/[dev.mokkery.matcher.varargs](../../index.md)/[VarArgMatcher](../index.md)/[AnyOf](index.md)

# AnyOf

@DelicateMokkeryApi

class [AnyOf](index.md)(type: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;) : [VarArgMatcher.Base](../-base/index.md)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; 

Matches any sequence of varargs.

#### Parameters

common

| | |
|---|---|
| type | of vararg element to provide vararg type information in [AnyOf.toString](to-string.md) |

## Constructors

| | |
|---|---|
| [AnyOf](-any-of.md) | [common]<br>constructor(type: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;) |

## Functions

| Name | Summary |
|---|---|
| [equals](equals.md) | [common]<br>open operator override fun [equals](equals.md)(other: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | [common]<br>open override fun [hashCode](hash-code.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [matches](../-base/matches.md) | [common]<br>override fun [matches](../-base/matches.md)(arg: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [matchesVarargs](matches-varargs.md) | [common]<br>open override fun [matchesVarargs](matches-varargs.md)(varargs: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [propagateCapture](../../../dev.mokkery.matcher.capture/propagate-capture.md) | [common]<br>fun &lt;[T](../../../dev.mokkery.matcher.capture/propagate-capture.md)&gt; [ArgMatcher](../../../dev.mokkery.matcher/-arg-matcher/index.md)&lt;[T](../../../dev.mokkery.matcher.capture/propagate-capture.md)&gt;.[propagateCapture](../../../dev.mokkery.matcher.capture/propagate-capture.md)(value: [T](../../../dev.mokkery.matcher.capture/propagate-capture.md))<br>Helper function to propagate capture for [dev.mokkery.matcher.ArgMatcher.Composite](../../../dev.mokkery.matcher/-arg-matcher/-composite/index.md). |
| [toString](to-string.md) | [common]<br>open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
